@@ -1,6 +1,7 @@
 package Hailo::Tokenizer::Characters;
-
+use 5.10.0;
 use Moose;
+use MooseX::StrictConstructor;
 use List::MoreUtils qw<uniq>;
 use Text::Trim;
 use namespace::clean -except => 'meta';
